@@ -2,12 +2,27 @@
 
 ;; Author: Gino Cornejo
 ;; Mantainer: Gino Cornejo <gggion123@gmail.com>
-;; Package-Version: 1.1.0
-;; Package-Revision: 75a7a3f7cbda
+;; Package-Version: 20251123.1932
+;; Package-Revision: 3379f337efe0
 ;; Package-Requires: ((emacs "29.1"))
 ;; Keywords: lisp, docs, editing
 ;; URL: https://github.com/gggion/lisp-docstring-toggle
 
+;; SPDX-License-Identifier: GPL-3.0-or-later
+
+;; This file is free software: you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published
+;; by the Free Software Foundation, either version 3 of the License,
+;; or (at your option) any later version.
+;;
+;; This file is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;;
+;; You should have received a copy of the GNU General Public License
+;; along with this file.  If not, see <https://www.gnu.org/licenses/>.
+
 ;;; Commentary:
 ;;
 ;; This package provides commands to toggle the visibility of Lisp
@@ -586,15 +601,13 @@ added to global hooks."
 
 This mode provides keybindings for docstring toggling commands.
 
-Default keybindings (customizable via `lisp-docstring-toggle-keymap-prefix'):
-
 \\<lisp-docstring-toggle-command-map>
 \\[lisp-docstring-toggle] - Toggle all docstrings in buffer
 \\[lisp-docstring-toggle-at-point] - Toggle docstring at point
 \\[lisp-docstring-toggle-debug-show-docstring-snippets] - Show debug information
 
-The default prefix is C-c , but you can customize it. For example,
-if C-c C-d doesn't conflict with your major modes:
+The prefix key is customizable via `lisp-docstring-toggle-keymap-prefix'.
+For example:
 
     (setq lisp-docstring-toggle-keymap-prefix \"C-c C-d\")
 
